@@ -21,18 +21,31 @@ def __update_output_dictionary_to_values__(dictionary, values, output_values):
 
 
 class TransformerHandler:
+    """
+    TransformerHandler administrates the different passed transformations for HistoDataset.
+    """
     def __init__(
         self,
         transfs: O[U[Callable, Sequence[Callable]]] = None,
         access_orders: O[Sequence[Sequence[str]]] = None,
         is_callable_with_batches: O[Sequence[bool]] = None,
-        seed: int = None,
+        seed: O[int] = None,
     ):
+        """
+        TODO
+
+        Arguments:
+            transfs: TODO
+            access_orders: TODO
+            trais_callable_with_batchesnsfs: TODO
+            seed: TODO
+        """
+
         # convert or create list of pre_transformation_adapters
         self.transfs = helper.create_list_from_variable(transfs)
 
         # create a new access_orders list
-        if access_orders is not None:
+        if access_orders:
             if len(self.transfs) != len(access_orders):
                 assert AssertionError(
                     "The list of transformers and the list of access_order must be have "
@@ -45,7 +58,7 @@ class TransformerHandler:
             self.access_orders = [[] for _ in self.transfs]
 
         # create a new is_callable_with_batches list
-        if is_callable_with_batches is not None:
+        if is_callable_with_batches:
             if len(self.transfs) != len(is_callable_with_batches):
                 assert AssertionError(
                     "The list of transformers and the list of is_callable_with_batches "
@@ -57,7 +70,17 @@ class TransformerHandler:
 
         self.seed = seed
 
-    def append(self, trans, access_order=None, is_callable_with_batches=False):
+    def append(self, trans, access_order = None, is_callable_with_batches: bool = False):
+        """
+        TODO
+
+        Arguments:
+            trans: TODO
+            access_order: TODO
+            is_callable_with_batches: TODO
+            
+        """
+
         self.transfs.append(trans)
         if isinstance(access_order, str):
             access_order = [access_order]
@@ -67,7 +90,18 @@ class TransformerHandler:
         else:
             self.is_callable_with_batches.append(is_callable_with_batches)
 
-    def replace(self, trans, access_order=None, is_callable_with_batches=False, index=-1):
+    def replace(self, trans, access_order=None, is_callable_with_batches: bool = False, index: int = -1):
+        """
+        TODO
+
+        Arguments:
+            trans: TODO
+            access_order: TODO
+            is_callable_with_batches: TODO
+            index: TODO
+            
+        """
+
         self.transfs[index] = trans
         if isinstance(access_order, str):
             access_order = [access_order]
@@ -80,15 +114,29 @@ class TransformerHandler:
     def __call_single_transform_with_dict__(
         self, item_or_batch, hashes, transf, dictionary, batch_callable
     ):
+        """
+        TODO
+
+        Arguments:
+            item_or_batch: TODO
+            hashes: TODO
+            transf: TODO
+            dictionary: TODO
+            batch_callable: TODO
+
+        Returns:
+            TODO: TODO
+        """
+
         is_batch = isinstance(hashes, list)
 
         if is_batch is False:
-            if self.seed is not None:
+            if self.seed:
                 helper.set_random_seed_with_int(int(self.seed + hashes))
             input_dic = __set_values_to_input_dictionary__(dictionary, item_or_batch)
             result = transf(**input_dic)
             return __update_output_dictionary_to_values__(dictionary, item_or_batch, result)
-        elif batch_callable and self.seed is None:
+        elif batch_callable and self.seed:
             input_dic = __set_values_to_input_dictionary__(dictionary, item_or_batch)
             result = transf(**input_dic)
             item_or_batch.update(result)
@@ -106,6 +154,20 @@ class TransformerHandler:
     def __call_single_transform_with_callable__(
         self, item_or_batch, hashes, transf, order, batch_callable
     ):
+        """
+        TODO
+
+        Arguments:
+            item_or_batch: TODO
+            hashes: TODO
+            transf: TODO
+            order: TODO
+            batch_callable: TODO
+
+        Returns:
+            TODO: TODO
+        """
+
         is_batch = isinstance(hashes, list)
 
         if order is None or order == [] or order[0] is None or order[0] == "":
@@ -118,7 +180,7 @@ class TransformerHandler:
             element = item_or_batch.pop(name)
 
             if is_batch is False:
-                if self.seed is not None:
+                if self.seed:
                     helper.set_random_seed_with_int(int(self.seed + hashes))
                 result = transf(element)
             elif batch_callable and self.seed is None:
@@ -126,7 +188,7 @@ class TransformerHandler:
             else:
                 result = {}
                 for j, item in enumerate(element):
-                    if self.seed is not None:
+                    if self.seed:
                         helper.set_random_seed_with_int(int(self.seed + hashes[j]))
 
                     result_item = transf(item)
@@ -160,8 +222,18 @@ class TransformerHandler:
         return item_or_batch
 
     def __call__(self, item_or_batch, hashes):
+        """
+        TODO
 
-        if self.seed is not None:
+        Arguments:
+            item_or_batch: TODO
+            hashes: TODO
+
+        Returns:
+            TODO: TODO
+        """
+
+        if self.seed:
             saved_seed_state = helper.get_random_seed()
 
         for (transf, order, batch_callable) in zip(
@@ -176,17 +248,31 @@ class TransformerHandler:
                     item_or_batch, hashes, transf, order, batch_callable
                 )
 
-        if self.seed is not None:
+        if self.seed:
             helper.set_random_seed(*saved_seed_state)
 
         return item_or_batch
 
     def __len__(self):
+        """
+        Returns length of attribute transfs.
+        """
+        
         return len(self.transfs)
 
-    def __call_with_prints__(self, item_or_batch, hashes):
+    def __call_with_prints__(self, item_or_batch, hashes):        
+        """
+        TODO
 
-        if self.seed is not None:
+        Arguments:
+            item_or_batch: TODO
+            hashes: TODO
+
+        Returns:
+            TODO: TODO
+        """
+
+        if self.seed:
             saved_seed_state = helper.get_random_seed()
 
         index = 0
@@ -209,7 +295,7 @@ class TransformerHandler:
             print("All Output-keys:", list(item_or_batch))
             print()
 
-        if self.seed is not None:
+        if self.seed:
             helper.set_random_seed(*saved_seed_state)
 
         return item_or_batch
