@@ -39,10 +39,10 @@ def mai_patches(
                        last (the 9th) should be used only for testing.
                        The list contains numbers between 0 and 9.
         subset: which part of the dataset should be used.
-                       One of {"train", "valid", "test", "all"}
+                       One of {"train", "validation", "test", "all"}
                        This parameter is only used if folds is not set.
                        "train" equals folds: [0,1,2,3,4,5,6],
-                       "valid" equals folds: [7,8],
+                       "validation" equals folds: [7,8],
                        "test" equals folds: [9]
         gt_mode (str): The pathologist take a look at the slides three times
                        (GT1, GT2, GT3). One of the following modes are allowed:
@@ -92,15 +92,18 @@ def mai_patches(
                       a dictionary back.
     """
     if folds is None and subset is not None:
-        if subset == "train":
+        subset = subset.lower()
+        if subset.startswith("tr"):
             folds = [0, 1, 2, 3, 4, 5, 6]
-        elif subset == "val":
+        elif subset.startswith("val"):
             folds = [7, 8]
-        elif subset == "test":
+        elif subset.startswith("te"):
             folds = [9]
+        elif subset == "all":
+            pass
         else:
             raise AttributeError(
-                "Such type is not supported. Please choose the subset 'train', 'val' or 'test'."
+                "Such type is not supported. Please choose the subset 'train', 'validation' or 'test'."
             )
 
     if folds is not None:
@@ -260,7 +263,7 @@ def mai_patches_bern(
 
 def mai_he_and_phh3_fields(
     root: str,
-    split: str,
+    subset: str,
     splitting_seed: O[int] = 69,
     transformation: O[U[Callable, Sequence[Callable]]] = None,
     pre_transformation: O[U[Callable, Sequence[Callable]]] = None,
@@ -278,8 +281,8 @@ def mai_he_and_phh3_fields(
 
     Args:
         root (str): The path to the dataset.
-        split (str): which part of the dataset should be used.
-                       One of {"train", "valid", "test", "all"}
+        subset (str): which part of the dataset should be used.
+                       One of {"train", "validation", "test", "all"}
         splitting_seed (int): The splitting seed that is used to create
                        the datasets.
         splitting_trainings_percentage (float): 0.0 < x < 1.0, the percentage
@@ -331,13 +334,15 @@ def mai_he_and_phh3_fields(
         manipulators_to_use = [
             df_manipulators.EditDFImageGrid(patch_size, overlapping_percentage, (2048, 2048))
         ]
-    if split == "train":
+    if subset:
+        subset = subset.lower()
+    if subset.startswith("tr"):
         manipulators_to_use.append(
             df_manipulators.RandomFilterByColumnValue(
                 "base", splitting_trainings_percentage, mode=0, seed=splitting_seed
             )
         )
-    elif split == "valid":
+    elif subset.startswith("val"):
         manipulators_to_use.extend(
             [
                 df_manipulators.RandomFilterByColumnValue(
@@ -348,7 +353,7 @@ def mai_he_and_phh3_fields(
                 ),
             ]
         )
-    elif split == "test":
+    elif subset.startswith("te"):
         manipulators_to_use.extend(
             [
                 df_manipulators.RandomFilterByColumnValue(
@@ -359,11 +364,11 @@ def mai_he_and_phh3_fields(
                 ),
             ]
         )
-    elif split == "all":
+    elif subset == "all":
         pass
     else:
         raise NotImplementedError(
-            'The parameter "split" needs to be one of ["train", "valid", "test", "all"].'
+            'The parameter "subset" needs to be one of ["train", "validation", "test", "all"].'
         )
 
     if stain_mode == "phh3":
